@@ -1,7 +1,7 @@
 # Honeybee: A Plugin for Environmental Analysis (GPL)
 # This file is part of Honeybee.
 #
-# Copyright (c) 2020, Ladybug Tools.
+# Copyright (c) 2021, Ladybug Tools.
 # You should have received a copy of the GNU General Public License
 # along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
 # 
@@ -21,7 +21,8 @@ than systems that separate ventilation from the meeting of thermal loads.
         _df_objs: Dragonfly Buildings, Stories or Room2Ds to which the input template
             HVAC will be assigned. If a list of Room2Ds is input, all objects
             will receive the same HVAC instance. Otherwise, each object gets its
-            own instance (eg. each input Story will get its own HVAC).
+            own instance (eg. each input Story will get its own HVAC). This can
+            also be an etire dragonfly Model.
         _system_type: Text for the specific type of all-air system and equipment.
             The "HB All-Air HVAC Templates" component has a full list of the
             supported all-air system templates.
@@ -36,22 +37,25 @@ than systems that separate ventilation from the meeting of thermal loads.
             HVAC system. Economizers will mix in a greater amount of outdoor
             air to cool the zone (rather than running the cooling system) when
             the zone needs cooling and the outdoor air is cooler than the zone.
-            Choose from the options below. If Inferred, the economizer will be set
-            to whatever is recommended for the given vintage. Default: Inferred.
-                * Inferred
+            Choose from the options below. (Default: NoEconomizer).
                 * NoEconomizer
                 * DifferentialDryBulb
                 * DifferentialEnthalpy
+                * DifferentialDryBulbAndEnthalpy
+                * FixedDryBulb
+                * FixedEnthalpy
+                * ElectronicEnthalpy
         sensible_hr_: A number between 0 and 1 for the effectiveness of sensible
             heat recovery within the system. Typical values range from 0.5 for
             simple glycol loops to 0.81 for enthalpy wheels (the latter tends to
-            be fiarly expensive for air-based systems) Default: auto-calculated
-            by vintage (usually 0 for no heat recovery).
+            be fiarly expensive for air-based systems). (Default: 0).
         latent_hr_: A number between 0 and 1 for the effectiveness of latent heat
             recovery within the system. Typical values are 0 for all types of
             heat recovery except enthalpy wheels, which can have values as high
-            as 0.76. Default: auto-calculated by vintage (usually 0 for no heat
-            recovery).
+            as 0.76. (Default: 0).
+        dcv_: Boolean to note whether demand controlled ventilation should be
+            used on the system, which will vary the amount of ventilation air
+            according to the occupancy schedule of the zone. (Default: False).
 
     Returns:
         df_objs: The input Dragonfly objects with an all-air HVAC system applied.
@@ -59,19 +63,16 @@ than systems that separate ventilation from the meeting of thermal loads.
 
 ghenv.Component.Name = "DF All-Air HVAC"
 ghenv.Component.NickName = 'DFAllAirHVAC'
-ghenv.Component.Message = '1.1.1'
+ghenv.Component.Message = '1.2.2'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
 
 import os
 import json
-import uuid
 
 try:  # import the honeybee extension
-    from honeybee.altnumber import autosize
-    from honeybee.typing import clean_and_id_ep_string
-    from honeybee.model import Model
+    from honeybee.typing import clean_and_id_ep_string, clean_ep_string
 except ImportError as e:
     raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
 
@@ -82,8 +83,10 @@ except ImportError as e:
     raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))
 
 try:  # import the core dragonfly dependencies
+    from dragonfly.model import Model
     from dragonfly.building import Building
     from dragonfly.story import Story
+    from dragonfly.room2d import Room2D
 except ImportError as e:
     raise ImportError('\nFailed to import dragonfly:\n\t{}'.format(e))
 
@@ -131,7 +134,7 @@ if all_required_inputs(ghenv.Component):
     # duplicate the initial objects
     df_objs = [obj.duplicate() for obj in _df_objs]
 
-    # create the instance of the HVAC system to be applied to the objects
+    # process any input properties for the HVAC system
     try:  # get the class for the HVAC system
         try:
             _sys_name = hvac_dict[_system_type]
@@ -142,13 +145,18 @@ if all_required_inputs(ghenv.Component):
         raise ValueError('System Type "{}" is not recognized as an all-air HVAC '
                          'system.'.format(_system_type))
     vintage = vintages[_vintage_]  # get the vintage of the HVAC
-    # set default values for economizer and heat recovery
-    econ = _economizer_ if _economizer_ is not None else 'Inferred'
-    sens = sensible_hr_ if sensible_hr_ is not None else autosize
-    latent = latent_hr_ if latent_hr_ is not None else autosize
-    # get an identifier for the HVAC system
-    name = clean_and_id_ep_string(_name_) if _name_ is not None else str(uuid.uuid4())[:8]
-    hvac = hvac_class(name, vintage, _sys_name, econ, sens, latent)
+    name = clean_and_id_ep_string('All-Air HVAC') if _name_ is None else clean_ep_string(_name_)
+
+    # create the HVAC
+    hvac = hvac_class(name, vintage, _sys_name)
+    if _economizer_ is not None:
+        hvac.economizer_type = _economizer_
+    if sensible_hr_ is not None:
+        hvac.sensible_heat_recovery = sensible_hr_
+    if latent_hr_ is not None:
+        hvac.latent_heat_recovery = latent_hr_
+    if dcv_:
+        hvac.demand_controlled_ventilation = True
     if _name_ is not None:
         hvac.display_name = _name_
 
@@ -156,5 +164,12 @@ if all_required_inputs(ghenv.Component):
     for obj in df_objs:
         if isinstance(obj, (Building, Story)):
             obj.properties.energy.set_all_room_2d_hvac(hvac)
-        elif obj.properties.energy.is_conditioned:  # assume it's a Room2D
+        elif isinstance(obj, Room2D) and obj.properties.energy.is_conditioned:
             obj.properties.energy.hvac = hvac
+        elif isinstance(obj, Model):
+            for bldg in obj.buildings:
+                bldg.properties.energy.set_all_room_2d_hvac(hvac)
+        else:
+            raise ValueError(
+                'Expected Dragonfly Room2D, Story, Building, or Model. '
+                'Got {}.'.format(type(hb_obj)))
