@@ -1,7 +1,7 @@
 # Honeybee: A Plugin for Environmental Analysis (GPL)
 # This file is part of Honeybee.
 #
-# Copyright (c) 2020, Ladybug Tools.
+# Copyright (c) 2021, Ladybug Tools.
 # You should have received a copy of the GNU General Public License
 # along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
 # 
@@ -28,7 +28,8 @@ like auditoriums, kitchens, laundromats, etc.
         _df_objs: Dragonfly Buildings, Stories or Room2Ds to which the input template
             HVAC will be assigned. If a list of Room2Ds is input, all objects
             will receive the same HVAC instance. Otherwise, each object gets its
-            own instance (eg. each input Story will get its own HVAC).
+            own instance (eg. each input Story will get its own HVAC). This can
+            also be an etire dragonfly Model.
         _system_type: Text for the specific type of DOAS system and equipment.
             The "HB DOAS HVAC Templates" component has a full list of the
             supported DOAS system templates.
@@ -42,13 +43,20 @@ like auditoriums, kitchens, laundromats, etc.
         sensible_hr_: A number between 0 and 1 for the effectiveness of sensible
             heat recovery within the system. Typical values range from 0.5 for
             simple glycol loops to 0.81 for enthalpy wheels (the latter of
-            which is a fairly common ECM for DOAS systems) Default: auto-calculated
-            by vintage (usually 0 for no heat recovery).
+            which is a fairly common ECM for DOAS systems). (Default: 0).
         latent_hr_: A number between 0 and 1 for the effectiveness of latent heat
             recovery within the system. Typical values are 0 for all types of
             heat recovery except enthalpy wheels, which can have values as high
-            as 0.76. Default: auto-calculated by vintage (usually 0 for no heat
-            recovery).
+            as 0.76. (Default: 0).
+        dcv_: Boolean to note whether demand controlled ventilation should be
+            used on the system, which will vary the amount of ventilation air
+            according to the occupancy schedule of the zone. (Default: False).
+        doas_avail_sch_: An optional On/Off discrete schedule to set when the dedicated
+            outdoor air system (DOAS) shuts off. This will not only prevent
+            any outdoor air from flowing thorough the system but will also
+            shut off the fans, which can result in more energy savings when
+            spaces served by the DOAS are completely unoccupied. If None, the
+            DOAS will be always on. (Default: None).
 
     Returns:
         df_objs: The input Dragonfly objects with a DOAS HVAC system applied.
@@ -56,31 +64,31 @@ like auditoriums, kitchens, laundromats, etc.
 
 ghenv.Component.Name = 'DF DOAS HVAC'
 ghenv.Component.NickName = 'DFDOASHVAC'
-ghenv.Component.Message = '1.1.1'
+ghenv.Component.Message = '1.2.1'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
 
 import os
 import json
-import uuid
 
 try:  # import the honeybee extension
-    from honeybee.altnumber import autosize
-    from honeybee.typing import clean_and_id_ep_string
-    from honeybee.model import Model
+    from honeybee.typing import clean_and_id_ep_string, clean_ep_string
 except ImportError as e:
     raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
 
 try:  # import the honeybee-energy extension
     from honeybee_energy.config import folders
     from honeybee_energy.hvac.doas import EQUIPMENT_TYPES_DICT
+    from honeybee_energy.lib.schedules import schedule_by_identifier
 except ImportError as e:
     raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))
 
 try:  # import the core dragonfly dependencies
+    from dragonfly.model import Model
     from dragonfly.building import Building
     from dragonfly.story import Story
+    from dragonfly.room2d import Room2D
 except ImportError as e:
     raise ImportError('\nFailed to import dragonfly:\n\t{}'.format(e))
 
@@ -128,7 +136,7 @@ if all_required_inputs(ghenv.Component):
     # duplicate the initial objects
     df_objs = [obj.duplicate() for obj in _df_objs]
 
-    # create the instance of the HVAC system to be applied to the rooms
+    # process any input properties for the HVAC system
     try:  # get the class for the HVAC system
         try:
             _sys_name = hvac_dict[_system_type]
@@ -139,12 +147,14 @@ if all_required_inputs(ghenv.Component):
         raise ValueError('System Type "{}" is not recognized as a DOAS HVAC '
                          'system.'.format(_system_type))
     vintage = vintages[_vintage_]  # get the vintage of the HVAC
-    # set default values for heat recovery
-    sens = sensible_hr_ if sensible_hr_ is not None else autosize
-    latent = latent_hr_ if latent_hr_ is not None else autosize
-    # get an identifier for the HVAC system
-    name = clean_and_id_ep_string(_name_) if _name_ is not None else str(uuid.uuid4())[:8]
-    hvac = hvac_class(name, vintage, _sys_name, sens, latent)
+    name = clean_and_id_ep_string('DOAS HVAC') if _name_ is None else clean_ep_string(_name_)
+
+    # create the HVAC
+    hvac = hvac_class(name, vintage, _sys_name, sensible_hr_, latent_hr_, dcv_)
+    if doas_avail_sch_ is not None:
+        if isinstance(doas_avail_sch_, str):
+            doas_avail_sch_ = schedule_by_identifier(doas_avail_sch_)
+        hvac.doas_availability_schedule = doas_avail_sch_
     if _name_ is not None:
         hvac.display_name = _name_
 
@@ -152,5 +162,12 @@ if all_required_inputs(ghenv.Component):
     for obj in df_objs:
         if isinstance(obj, (Building, Story)):
             obj.properties.energy.set_all_room_2d_hvac(hvac)
-        elif obj.properties.energy.is_conditioned:  # assume it's a Room2D
+        elif isinstance(obj, Room2D) and obj.properties.energy.is_conditioned:
             obj.properties.energy.hvac = hvac
+        elif isinstance(obj, Model):
+            for bldg in obj.buildings:
+                bldg.properties.energy.set_all_room_2d_hvac(hvac)
+        else:
+            raise ValueError(
+                'Expected Dragonfly Room2D, Story, Building, or Model. '
+                'Got {}.'.format(type(hb_obj)))
