@@ -1,7 +1,7 @@
 # Honeybee: A Plugin for Environmental Analysis (GPL)
 # This file is part of Honeybee.
 #
-# Copyright (c) 2020, Ladybug Tools.
+# Copyright (c) 2021, Ladybug Tools.
 # You should have received a copy of the GNU General Public License
 # along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
 # 
@@ -23,7 +23,8 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
         _df_objs: Dragonfly Buildings, Stories or Room2Ds to which the input template
             HVAC will be assigned. If a list of Room2Ds is input, all objects
             will receive the same HVAC instance. Otherwise, each object gets its
-            own instance (eg. each input Story will get its own HVAC).
+            own instance (eg. each input Story will get its own HVAC). This can
+            also be an etire dragonfly Model.
         _system_type: Text for the specific type of heating/cooling system and equipment.
             The "HB HeatCool HVAC Templates" component has a full list of the
             supported Heating/Cooling system templates.
@@ -41,19 +42,17 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
 
 ghenv.Component.Name = "DF HeatCool HVAC"
 ghenv.Component.NickName = 'DFHeatCoolHVAC'
-ghenv.Component.Message = '1.1.1'
+ghenv.Component.Message = '1.2.1'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
 
 import os
 import json
-import uuid
 
 try:  # import the honeybee extension
     from honeybee.altnumber import autosize
-    from honeybee.typing import clean_and_id_ep_string
-    from honeybee.model import Model
+    from honeybee.typing import clean_and_id_ep_string, clean_ep_string
 except ImportError as e:
     raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
 
@@ -64,8 +63,10 @@ except ImportError as e:
     raise ImportError('\nFailed to import honeybee_energy:\n\t{}'.format(e))
 
 try:  # import the core dragonfly dependencies
+    from dragonfly.model import Model
     from dragonfly.building import Building
     from dragonfly.story import Story
+    from dragonfly.room2d import Room2D
 except ImportError as e:
     raise ImportError('\nFailed to import dragonfly:\n\t{}'.format(e))
 
@@ -113,7 +114,7 @@ if all_required_inputs(ghenv.Component):
     # duplicate the initial objects
     df_objs = [obj.duplicate() for obj in _df_objs]
 
-    # create the instance of the HVAC system to be applied to the rooms
+    # process any input properties for the HVAC system
     try:  # get the class for the HVAC system
         try:
             _sys_name = hvac_dict[_system_type]
@@ -124,8 +125,9 @@ if all_required_inputs(ghenv.Component):
         raise ValueError('System Type "{}" is not recognized as a HeatCool HVAC '
                          'system.'.format(_system_type))
     vintage = vintages[_vintage_]  # get the vintage of the HVAC
-    # get an identifier for the HVAC system
-    name = clean_and_id_ep_string(_name_) if _name_ is not None else str(uuid.uuid4())[:8]
+    name = clean_and_id_ep_string('Heat-Cool HVAC') if _name_ is None else clean_ep_string(_name_)
+
+    # create the HVAC
     hvac = hvac_class(name, vintage, _sys_name)
     if _name_ is not None:
         hvac.display_name = _name_
@@ -134,5 +136,12 @@ if all_required_inputs(ghenv.Component):
     for obj in df_objs:
         if isinstance(obj, (Building, Story)):
             obj.properties.energy.set_all_room_2d_hvac(hvac)
-        elif obj.properties.energy.is_conditioned:  # assume it's a Room2D
+        elif isinstance(obj, Room2D) and obj.properties.energy.is_conditioned:
             obj.properties.energy.hvac = hvac
+        elif isinstance(obj, Model):
+            for bldg in obj.buildings:
+                bldg.properties.energy.set_all_room_2d_hvac(hvac)
+        else:
+            raise ValueError(
+                'Expected Dragonfly Room2D, Story, Building, or Model. '
+                'Got {}.'.format(type(hb_obj)))
